==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebDockPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescriptionMetadata } from "./WebDockingIndicatorDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebDockPaneActionDescription } from "./WebDockPaneActionDescription";
/**
 * @hidden
 */
var WebDockPaneActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockPaneActionDescriptionMetadata, _super);
    function WebDockPaneActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockPaneActionDescriptionMetadata.b = function (a) {
        if (WebDockPaneActionDescriptionMetadata.a == null) {
            WebDockPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockPaneActionDescriptionMetadata.c(WebDockPaneActionDescriptionMetadata.a);
        }
        if (a.g(WebDockPaneActionDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockPaneActionDescriptionMetadata.a);
        WebDockingIndicatorDescriptionMetadata.d(a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebDockPaneActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DockPaneAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("DockingIndicator", "ExportedType:WebDockingIndicator");
        a.item("TargetPane", "ExportedType:WebDockManagerPane");
    };
    WebDockPaneActionDescriptionMetadata.d = function (a) {
        WebDockPaneActionDescriptionMetadata.b(a);
        a.u("WebDockPaneAction", function () { return new WebDockPaneActionDescription(); });
        a.t("WebDockPaneAction", WebDockPaneActionDescriptionMetadata.a);
    };
    WebDockPaneActionDescriptionMetadata.$t = markType(WebDockPaneActionDescriptionMetadata, 'WebDockPaneActionDescriptionMetadata');
    WebDockPaneActionDescriptionMetadata.a = null;
    return WebDockPaneActionDescriptionMetadata;
}(Base));
export { WebDockPaneActionDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDockPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescriptionMetadata } from "./WebDockingIndicatorDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebDockPaneActionDescription } from "./WebDockPaneActionDescription";
/**
 * @hidden
 */
var WebDockPaneActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockPaneActionDescriptionMetadata, _super);
    function WebDockPaneActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockPaneActionDescriptionMetadata.b = function (a) {
        if (WebDockPaneActionDescriptionMetadata.a == null) {
            WebDockPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockPaneActionDescriptionMetadata.c(WebDockPaneActionDescriptionMetadata.a);
        }
        if (a.j(WebDockPaneActionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockPaneActionDescriptionMetadata.a);
        WebDockingIndicatorDescriptionMetadata.d(a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebDockPaneActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DockPaneAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("DockingIndicator", "ExportedType:WebDockingIndicator");
        a.item("TargetPane", "ExportedType:WebDockManagerPane");
    };
    WebDockPaneActionDescriptionMetadata.d = function (a) {
        WebDockPaneActionDescriptionMetadata.b(a);
        a.aa("WebDockPaneAction", function () { return new WebDockPaneActionDescription(); });
        a.z("WebDockPaneAction", WebDockPaneActionDescriptionMetadata.a);
    };
    WebDockPaneActionDescriptionMetadata.$t = markType(WebDockPaneActionDescriptionMetadata, 'WebDockPaneActionDescriptionMetadata');
    WebDockPaneActionDescriptionMetadata.a = null;
    return WebDockPaneActionDescriptionMetadata;
}(Base));
export { WebDockPaneActionDescriptionMetadata };
